@@ -106,6 +106,12 @@ FEINCMS_DEFAULT_PAGE_MODEL = getattr(
 # ------------------------------------------------------------------------
 # Various settings
 
+#: Run the weak replacement for a real database migration solution?
+FEINCMS_CHECK_DATABASE_SCHEMA = getattr(
+    settings,
+    'FEINCMS_CHECK_DATABASE_SCHEMA',
+    True)
+
 # ------------------------------------------------------------------------
 #: Allow random gunk after a valid page?
 FEINCMS_ALLOW_EXTRA_PATH = getattr(
